@@ -26,13 +26,33 @@
     invisible()
 }
 
+.getDTEnv <- function(){
+    if (requireNamespace("data.table", quietly = TRUE)){
+        .env <- loadNamespace("data.table");
+        if (utils::compareVersion(as.character(
+                       utils::packageVersion("data.table")),
+                                  "1.12.4") >= 0){
+            return(.env)
+        } else {
+            return(new.env(parent=emptyenv()))
+        }
+    } else {
+        return(new.env(parent=emptyenv()))
+    }
+}
+
 .sortId <- function(idData, goodLvl, type="parameter",
                     warnIdSort){
     .n <- tolower(names(idData));
     .w <- which(.n == "id");
     .nid <- length(goodLvl);
     if (length(.w) == 1){
-        .idData <- as.data.frame(idData);
+        if (.nid == 1 && length(idData[[.w]]) == 1){
+            .idData <- as.data.frame(idData);
+            goodLvl <- paste(.idData[[.w]]);
+        } else {
+            .idData <- as.data.frame(idData);
+        }
         .oId <- .idData[[.w]];
         .idData[[.w]] <- factor(.idData[[.w]], levels=goodLvl, labels=goodLvl);
         .wrn <- ""
@@ -44,8 +64,9 @@
         }
         .idData <- .idData[order(.idData[[.w]]), ];
         .idData <- .idData[, -.w, drop = FALSE];
-        if (length(.idData[, 1]) == 0)
+        if (length(.idData[, 1]) == 0){
             stop(sprintf("There are no IDs left to solve in %s data", type))
+        }
         if (.wrn != "") warning(.wrn)
         return(.idData)
     } else if (length(.w) == 0L) {
