@@ -26,6 +26,7 @@
 .onUnload <- function (libpath) {
     ## nocov start
     rxUnloadAll();
+    gc(); # Force garbage collection finalization
     library.dynam.unload("RxODE", libpath)
     ## nocov end
 }
@@ -98,7 +99,9 @@ rxOpt <- list(RxODE.prefer.tbl               =c(FALSE, FALSE),
               RxODE.syntax.assign.state      =c(FALSE, FALSE),
               RxODE.tempfiles                =c(TRUE, TRUE),
               RxODE.sympy.run.internal       =c(FALSE, FALSE),
-              RxODE.syntax.require.ode.first =c(TRUE, TRUE)
+              RxODE.syntax.require.ode.first =c(TRUE, TRUE),
+              RxODE.compile.O                =c("2", "2"),
+              RxODE.unload.unused            =c(TRUE, TRUE)
               );
 
 RxODE.prefer.tbl <- NULL
@@ -121,6 +124,8 @@ RxODE.syntax.assign.state <- NULL
 RxODE.tempfiles <- NULL;
 RxODE.sympy.run.internal <- NULL
 RxODE.syntax.require.ode.first <- NULL
+RxODE.compile.O <- NULL
+RxODE.unload.unused <- NULL
 
 .isTestthat <- function(){
     return(regexpr("/tests/testthat/", getwd(), fixed=TRUE) != -1) # nolint
