@@ -390,8 +390,8 @@ static int dopcor (int *nptr, FcnEqDiff fcn, double x, double* y, double xend,
       solout (naccpt+1, xold, x, y, nptr, &irtrn); 
       if (irtrn < 0)
         {
-          if (fileout)
-            fprintf (fileout, "Exit of dop853 at x = %.16e\r\n", x);
+          /* if (fileout) */
+            Rprintf("Exit of dop853 at x = %.16e\r\n", x);
           return 2;
         }
     }
@@ -401,8 +401,8 @@ static int dopcor (int *nptr, FcnEqDiff fcn, double x, double* y, double xend,
     {
       if (nstep > nmax)
         {
-          if (fileout)
-            fprintf (fileout, "Exit of dop853 at x = %.16e, more than nmax = %li are needed\r\n", x, nmax);
+          /* if (fileout) */
+            Rprintf ( "Exit of dop853 at x = %.16e, more than nmax = %li are needed\r\n", x, nmax);
           xout = x;
           hout = h;
           return -2;
@@ -410,8 +410,8 @@ static int dopcor (int *nptr, FcnEqDiff fcn, double x, double* y, double xend,
 
       if (0.1 * fabs(h) <= fabs(x) * uround)
         {
-          if (fileout)
-            fprintf (fileout, "Exit of dop853 at x = %.16e, step size too small h = %.16e\r\n", x, h);
+          /* if (fileout) */
+            Rprintf ("Exit of dop853 at x = %.16e, step size too small h = %.16e\r\n", x, h);
           xout = x;
           hout = h;
           return -3;
@@ -543,14 +543,11 @@ static int dopcor (int *nptr, FcnEqDiff fcn, double x, double* y, double xend,
                   iasti++;
                   if (iasti == 15)
                     {
-                      if (fileout)
-                        fprintf (fileout, "The problem seems to become stiff at x = %.16e\r\n", x);
-                      else
-                        {
-                          xout = x;
-                          hout = h;
-                          return -4;
-                        }
+		      Rprintf ("The problem seems to become stiff at x = %.16e\r\n", x);                        
+
+		      xout = x;
+		      hout = h;
+		      return -4;
                     }
                 }
               else
@@ -661,8 +658,8 @@ static int dopcor (int *nptr, FcnEqDiff fcn, double x, double* y, double xend,
               solout (naccpt+1, xold, x, y, nptr, &irtrn);
               if (irtrn < 0)
                 {
-                  if (fileout)
-                    fprintf (fileout, "Exit of dop853 at x = %.16e\r\n", x);
+                  /* if (fileout) */
+                    Rprintf ( "Exit of dop853 at x = %.16e\r\n", x);
                   return 2;
                 }
             }
@@ -717,8 +714,8 @@ int dop853
   /* n, the dimension of the system */
   if (n == INT_MAX)
     {
-      if (fileout)
-        fprintf (fileout, "System too big, max. n = %u\r\n", INT_MAX-1);
+      /* if (fileout) */
+        Rprintf ("System too big, max. n = %u\r\n", INT_MAX-1);
       arret = 1;
     }
 
@@ -727,8 +724,8 @@ int dop853
     nmax = 100000;
   else if (nmax <= 0)
     {
-      if (fileout)
-        fprintf (fileout, "Wrong input, nmax = %li\r\n", nmax);
+      /* if (fileout) */
+        Rprintf ( "Wrong input, nmax = %li\r\n", nmax);
       arret = 1;
     }
 
@@ -737,8 +734,8 @@ int dop853
     meth = 1;
   else if ((meth <= 0) || (meth >= 2))
     {
-      if (fileout)
-        fprintf (fileout, "Curious input, meth = %i\r\n", meth);
+      /* if (fileout) */
+        Rprintf ("Curious input, meth = %i\r\n", meth);
       arret = 1;
     }
 
@@ -751,16 +748,16 @@ int dop853
   /* iout, switch for calling solout */
   if ((iout < 0) || (iout > 2))
     {
-      if (fileout)
-        fprintf (fileout, "Wrong input, iout = %i\r\n", iout);
+      /* if (fileout) */
+        Rprintf ( "Wrong input, iout = %i\r\n", iout);
       arret = 1;
     }
 
   /* nrdens, number of dense output components */
   if (nrdens > n)
     {
-      if (fileout)
-        fprintf (fileout, "Curious input, nrdens = %u\r\n", nrdens);
+      /* if (fileout) */
+        Rprintf ( "Curious input, nrdens = %u\r\n", nrdens);
       arret = 1;
     }
   else if (nrdens)
@@ -780,22 +777,22 @@ int dop853
       if (!rcont1 || !rcont2 || !rcont3 || !rcont4 || !rcont5 ||
           !rcont6 || !rcont7 || !rcont8 || (!indir && (nrdens < n)))
         {
-          if (fileout)
-            fprintf (fileout, "Not enough free memory for rcont12345678&indir\r\n");
+          /* if (fileout) */
+            Rprintf ( "Not enough free memory for rcont12345678&indir\r\n");
           arret = 1;
         }
 
       /* control of length of icont */
       if (nrdens == n)
         {
-          if (icont && fileout)
-            fprintf (fileout, "Warning : when nrdens = n there is no need allocating memory for icont\r\n");
+          if (icont)
+            Rprintf ( "Warning : when nrdens = n there is no need allocating memory for icont\r\n");
           nrds = n;
         }
       else if (licont < nrdens)
         {
-          if (fileout)
-            fprintf (fileout, "Insufficient storage for icont, min. licont = %u\r\n", nrdens);
+          /* if (fileout) */
+            Rprintf ( "Insufficient storage for icont, min. licont = %u\r\n", nrdens);
           arret = 1;
         }
       else
